@@ -58,11 +58,11 @@ class Package(Module):
         raise NotImplementedError
 
     def __repr__(self):
-        return "<package %s>" % (self.name,)
+        return "<package {}>".format(self.name)
 
     @classmethod
     def get_module_class(cls, host):
-        if host.system_info.type == 'windows':
+        if host.system_info.type == "windows":
             return ChocolateyPackage
         if host.system_info.type == "freebsd":
             return FreeBSDPackage
@@ -88,7 +88,6 @@ class Package(Module):
 
 
 class DebianPackage(Package):
-
     @property
     def is_installed(self):
         result = self.run_test("dpkg-query -f '${Status}' -W %s", self.name)
@@ -104,22 +103,24 @@ class DebianPackage(Package):
 
     @property
     def version(self):
-        out = self.check_output("dpkg-query -f '${Status} ${Version}' -W %s",
-                                self.name)
+        out = self.check_output("dpkg-query -f '${Status} ${Version}' -W %s", self.name)
         splitted = out.split()
-        assert splitted[0].lower() in ('install', 'hold'), (
-            "The package %s is not installed, dpkg-query output: %s" % (
-                self.name, out))
+        assert splitted[0].lower() in (
+            "install",
+            "hold",
+        ), "The package {} is not installed, dpkg-query output: {}".format(
+            self.name, out
+        )
         return splitted[3]
 
 
 class FreeBSDPackage(Package):
-
     @property
     def is_installed(self):
         EX_UNAVAILABLE = 69
-        return self.run_expect(
-            [0, EX_UNAVAILABLE], "pkg query %%n %s", self.name).rc == 0
+        return (
+            self.run_expect([0, EX_UNAVAILABLE], "pkg query %%n %s", self.name).rc == 0
+        )
 
     @property
     def release(self):
@@ -131,10 +132,9 @@ class FreeBSDPackage(Package):
 
 
 class OpenBSDPackage(Package):
-
     @property
     def is_installed(self):
-        return self.run_test("pkg_info -e %s", "%s-*" % (self.name,)).rc == 0
+        return self.run_test("pkg_info -e %s", "{}-*".format(self.name)).rc == 0
 
     @property
     def release(self):
@@ -142,31 +142,27 @@ class OpenBSDPackage(Package):
 
     @property
     def version(self):
-        out = self.check_output("pkg_info -e %s", "%s-*" % (self.name,))
+        out = self.check_output("pkg_info -e %s", "{}-*".format(self.name))
         # OpenBSD: inst:zsh-5.0.5p0
         # NetBSD: zsh-5.0.7nb1
         return out.split(self.name + "-", 1)[1]
 
 
 class RpmPackage(Package):
-
     @property
     def is_installed(self):
         return self.run_test("rpm -q %s", self.name).rc == 0
 
     @property
     def version(self):
-        return self.check_output('rpm -q --queryformat="%%{VERSION}" %s',
-                                 self.name)
+        return self.check_output('rpm -q --queryformat="%%{VERSION}" %s', self.name)
 
     @property
     def release(self):
-        return self.check_output('rpm -q --queryformat="%%{RELEASE}" %s',
-                                 self.name)
+        return self.check_output('rpm -q --queryformat="%%{RELEASE}" %s', self.name)
 
 
 class AlpinePackage(Package):
-
     @property
     def is_installed(self):
         return self.run_test("apk -e info %s", self.name).rc == 0
@@ -183,7 +179,6 @@ class AlpinePackage(Package):
 
 
 class ArchPackage(Package):
-
     @property
     def is_installed(self):
         return self.run_test("pacman -Q %s", self.name).rc == 0
@@ -199,15 +194,13 @@ class ArchPackage(Package):
 
 
 class ChocolateyPackage(Package):
-
     @property
     def is_installed(self):
         return self.run_test("choco info -lo %s", self.name).rc == 0
 
     @property
     def version(self):
-        _, version = self.check_output(
-            "choco info -lo %s -r", self.name).split("|", 1)
+        _, version = self.check_output("choco info -lo %s -r", self.name).split("|", 1)
         return version
 
     @property
